@@ -5,7 +5,7 @@
 from __future__ import print_function # pyflakes
 
 app_name = 'unity-mail'
-app_version = '1.2'
+app_version = '1.3'
 
 import imaplib
 import email
@@ -22,7 +22,8 @@ import secretstorage
 
 from socket import error as socketerror
 from gi.repository import GLib, Gtk, Notify
-from secretstorage.exceptions import SecretServiceNotAvailableException
+from secretstorage.exceptions import SecretServiceNotAvailableException, \
+ ItemNotFoundException
 
 from UnityMail import gettext, Unity, Dbusmenu, MessagingMenu, \
  with_unity, with_messagingmenu
@@ -239,19 +240,18 @@ class UnityMail(object):
 	
 	def init_keyring(self):
 		bus = secretstorage.dbus_init()
-		self.collection = secretstorage.Collection(bus)
 		try:
-			locked = self.collection.is_locked()
-		except SecretServiceNotAvailableException:
-			# Sleep a second and try to read the collection by alias
-			time.sleep(1)
+			self.collection = secretstorage.Collection(bus)
+			self.collection.is_locked()
+		except SecretServiceNotAvailableException as e:
+			sys.exit(e)
+		except ItemNotFoundException:
 			try:
-				self.collection = secretstorage.get_collection_by_alias(
-					bus, 'default')
-				locked = self.collection.is_locked()
-			except SecretServiceNotAvailableException as e:
+				self.collection = secretstorage.create_collection(bus,
+				'Default', 'default')
+			except ItemNotFoundException as e:
 				sys.exit(e)
-		if locked:
+		if self.collection.is_locked():
 			self.collection.unlock()
 		if self.collection.is_locked():
 			sys.exit('unity-mail: Failed to unlock the collection; exiting')
@@ -426,9 +426,11 @@ class UnityMail(object):
 		self.mail_client[cn].close()
 	
 	def check_email(self, cn, email):
-		login, host = email.split('@')
 		if self.login[cn] == email:
 			return True
+		if '@' not in email:
+			return False
+		login, host = email.rsplit('@', 1)
 		return (self.login[cn] == login) and self.host[cn].endswith(host)
 	
 	def get_urlid(self, cn):
